==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OAuth2RefreshTokenLinksAllOfRevoke.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OAuth2RefreshTokenLinksAllOfRevokeAllOfHints;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Link to revoke the refresh Token
 */
@ApiModel(description = "Link to revoke the refresh Token")
@JsonPropertyOrder({ OAuth2RefreshTokenLinksAllOfRevoke.JSON_PROPERTY_HREF,
        OAuth2RefreshTokenLinksAllOfRevoke.JSON_PROPERTY_HINTS })
@JsonTypeName("OAuth2RefreshToken__links_allOf_revoke")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OAuth2RefreshTokenLinksAllOfRevoke implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_HREF = "href";
    private String href;

    public static final String JSON_PROPERTY_HINTS = "hints";
    private OAuth2RefreshTokenLinksAllOfRevokeAllOfHints hints;

    public OAuth2RefreshTokenLinksAllOfRevoke() {
    }

    public OAuth2RefreshTokenLinksAllOfRevoke href(String href) {

        this.href = href;
        return this;
    }

    /**
     * Link URI
     *
     * @return href
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "https://{yourOktaDomain}/api/v1/users/00u5t60iloOHN9pBi0h7/clients/0oabskvc6442nkvQO0h7/tokens/oar579Mcp7OUsNTlo0g3", value = "Link URI")
    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getHref() {
        return href;
    }

    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHref(String href) {
        this.href = href;
    }

    public OAuth2RefreshTokenLinksAllOfRevoke hints(OAuth2RefreshTokenLinksAllOfRevokeAllOfHints hints) {

        this.hints = hints;
        return this;
    }

    /**
     * Get hints
     *
     * @return hints
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints getHints() {
        return hints;
    }

    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHints(OAuth2RefreshTokenLinksAllOfRevokeAllOfHints hints) {
        this.hints = hints;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OAuth2RefreshTokenLinksAllOfRevoke oauth2RefreshTokenLinksAllOfRevoke = (OAuth2RefreshTokenLinksAllOfRevoke) o;
        return Objects.equals(this.href, oauth2RefreshTokenLinksAllOfRevoke.href)
                && Objects.equals(this.hints, oauth2RefreshTokenLinksAllOfRevoke.hints);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(href, hints);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OAuth2RefreshTokenLinksAllOfRevoke {\n");
        sb.append("    href: ").append(toIndentedString(href)).append("\n");
        sb.append("    hints: ").append(toIndentedString(hints)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OAuth2RefreshTokenLinksAllOfRevoke.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OAuth2RefreshTokenLinksAllOfRevokeAllOfHints;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Link to revoke the refresh Token
 */
@ApiModel(description = "Link to revoke the refresh Token")
@JsonPropertyOrder({ OAuth2RefreshTokenLinksAllOfRevoke.JSON_PROPERTY_HREF,
        OAuth2RefreshTokenLinksAllOfRevoke.JSON_PROPERTY_HINTS })
@JsonTypeName("OAuth2RefreshToken__links_allOf_revoke")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class OAuth2RefreshTokenLinksAllOfRevoke implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_HREF = "href";
    private String href;

    public static final String JSON_PROPERTY_HINTS = "hints";
    private OAuth2RefreshTokenLinksAllOfRevokeAllOfHints hints;

    public OAuth2RefreshTokenLinksAllOfRevoke() {
    }

    public OAuth2RefreshTokenLinksAllOfRevoke href(String href) {

        this.href = href;
        return this;
    }

    /**
     * Link URI
     *
     * @return href
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "https://{yourOktaDomain}/api/v1/users/00u5t60iloOHN9pBi0h7/clients/0oabskvc6442nkvQO0h7/tokens/oar579Mcp7OUsNTlo0g3", value = "Link URI")
    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getHref() {
        return href;
    }

    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHref(String href) {
        this.href = href;
    }

    public OAuth2RefreshTokenLinksAllOfRevoke hints(OAuth2RefreshTokenLinksAllOfRevokeAllOfHints hints) {

        this.hints = hints;
        return this;
    }

    /**
     * Get hints
     *
     * @return hints
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints getHints() {
        return hints;
    }

    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHints(OAuth2RefreshTokenLinksAllOfRevokeAllOfHints hints) {
        this.hints = hints;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OAuth2RefreshTokenLinksAllOfRevoke oauth2RefreshTokenLinksAllOfRevoke = (OAuth2RefreshTokenLinksAllOfRevoke) o;
        return Objects.equals(this.href, oauth2RefreshTokenLinksAllOfRevoke.href)
                && Objects.equals(this.hints, oauth2RefreshTokenLinksAllOfRevoke.hints);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(href, hints);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OAuth2RefreshTokenLinksAllOfRevoke {\n");
        sb.append("    href: ").append(toIndentedString(href)).append("\n");
        sb.append("    hints: ").append(toIndentedString(hints)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
